@@ -2,14 +2,14 @@ import traceback
 
 from sqlalchemy.exc import SQLAlchemyError
 
-from bolinette import blnt
+from bolinette import abc, blnt
 from bolinette.exceptions import APIError, APIErrors, InternalError
 
 
-class Transaction:
+class Transaction(abc.WithContext):
     def __init__(self, context: 'blnt.BolinetteContext', *,
                  print_error: bool = True, propagate_error: bool = True, raise_internal: bool = True):
-        self.context = context
+        super().__init__(context)
         self.print_error = print_error
         self.propagate_error = propagate_error
         self.raise_internal = raise_internal
