@@ -1,5 +1,6 @@
 from bolinette.core import functions
-from bolinette.core.models import Model, ModelMetadata, ModelProperty
+from bolinette.core.models import Model
+import bolinette.core.models as models
 from bolinette.core.mixin import Mixin, MixinServiceMethod
 from bolinette.core.repository import Repository
 from bolinette.core.service import Service, ServiceMetadata, SimpleService
