@@ -1,16 +1,16 @@
 import bcrypt
 
-from bolinette import core, blnt
-from bolinette.decorators import service, injected
-from bolinette.defaults.services import FileService
+from bolinette import abc, core
+from bolinette.decorators import service
 from bolinette.exceptions import ForbiddenError, UnprocessableEntityError
+from bolinette.defaults.services import FileService
 
 
 @service('user')
 class UserService(core.Service):
-    @injected
-    def file_server(self, inject: 'blnt.BolinetteInjection') -> FileService:
-        return inject.services.require('file')
+    def __init__(self, context: abc.Context, file_service: FileService):
+        super().__init__(context)
+        self.file_service = file_service
 
     @staticmethod
     def encrypt_password(password):
